%undefine __cmake_in_source_build
%global srcname flann
%global soversion 1.9

Name:           flann
Version:        1.9.2
Release:        1%{?dist}
Summary:        Fast Library for Approximate Nearest Neighbors

License:        BSD
URL:            http://www.cs.ubc.ca/research/flann
Source0:        https://www.github.com/mariusmuja/%{name}/archive/%{version}/%{name}-%{version}.tar.gz

# Prevent the buildsysem from running setup.py, and use system-installed libflann.so
# Not submitted upstream
Patch0:         flann-1.9.1-fixpyflann.patch
# Distutils -> Setuptools
Patch3:         flann-1.9.2-py3.12.patch
# Install cmake scripts to correct libdir
Patch4:         flann-1.9.2-cmakeinstall.patch
# Fix pkgconfig file generation
Patch5:         flann-1.9.2-pkgconfig.patch

BuildRequires:  gcc-c++
BuildRequires:  cmake
BuildRequires:  zlib-devel
BuildRequires:  lz4-devel

BuildRequires:  hdf5-devel
BuildRequires:  gtest-devel

BuildRequires:  latex2html
BuildRequires:  texlive-bibtex
BuildRequires:  texlive-latex

BuildRequires:  python3-devel
BuildRequires:  python3-setuptools

%description
FLANN is a library for performing fast approximate nearest neighbor searches
in high dimensional spaces. It contains a collection of algorithms found
to work best for nearest neighbor search and a system for automatically
choosing the best algorithm and optimum parameters depending on the data sets.

%package devel
Summary: Development headers and libraries for flann
Requires: %{name}%{?_isa} = %{version}-%{release}
# flann/flann_mpi.hpp requires boost/mpi.hpp, which is a convenience header
# inside of the boost-devel package
Requires: boost-devel
# The cmake files get very unhappy if they can't find the static libs
Requires: %{name}-static%{?_isa} = %{version}-%{release}
# lz4 headers are exposed in the public API
Requires: lz4-devel

%description devel
Development headers and libraries for flann.

%package static
Summary: Static libraries for flann
Requires: %{name}-devel%{?_isa} = %{version}-%{release}

%description static
Static libraries for flann.

%package -n python3-flann
Summary: Python bindings for flann
Requires: %{name}%{?_isa} = %{version}-%{release}
Requires: python3-numpy
%{?python_provide:%python_provide python3-%{srcname}}

%description -n python3-flann
Python 3 bindings for flann

%prep
%setup 
%patch 0 -p0 -b .fixpyflann
%patch 3 -p0 -b .py3.12
%patch 4 -p0 -b .cmakeinstall
%patch 5 -p0 -b .pkgconfig

# Fix library install directory
sed -i 's/"lib"/"%{_lib}"/' cmake/flann_utils.cmake

%build
%cmake -DBUILD_MATLAB_BINDINGS=OFF -DCMAKE_BUILD_TYPE=Release -DBUILD_PYTHON_BINDINGS=ON 
%cmake_build
%cmake_build --target doc

%install
%cmake_install
rm -rf %{buildroot}%{_datadir}/%{name}/python

# install the python bindings
cp -r src/python src/python3

cp %{_vpath_builddir}/src/python/setup.py src/python3

pushd src/python3
%{__python3} setup.py install --prefix=/usr --root=%{buildroot} --install-lib=%{python3_sitearch}
popd

# get rid of duplicate shared libraries
rm -rf %{buildroot}%{python3_sitearch}/pyflann/lib
# Remove example binaries
rm -rf %{buildroot}%{_bindir}*
# Remove installed documentation, we'll install it later with the doc macro
rm -rf %{buildroot}%{_datadir}/doc/flann

%files
%doc doc/manual.pdf
%{_libdir}/*.so.%{version}
%{_libdir}/*.so.%{soversion}

%files devel
%{_libdir}/*.so
%{_libdir}/pkgconfig/*
%{_includedir}/flann
%{_libdir}/cmake/flann

%files static
%{_libdir}/*.a

%files -n python3-%{srcname}
%{python3_sitearch}/pyflann
%{python3_sitearch}/flann-%{version}*.egg-info

%changelog
* Wed Sep 11 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.9.2-1
- initial build

